/// <reference types="react" />
import React from 'react';
import { ReactNode } from "react";
import { PermissionsMap } from '@stytch/core/public';
import { Member, MemberSession, Organization, StytchB2BUIClient } from '@stytch/vanilla-js/b2b';
import { StytchB2BHeadlessClient, StytchProjectConfigurationInput } from '@stytch/vanilla-js/b2b/headless';
/**
 * The Stytch Client object passed in to <StytchB2BProvider /> in your application root.
 * Either a StytchB2BUIClient or StytchB2BHeadlessClient.
 */
type StytchB2BClient<TProjectConfiguration extends StytchProjectConfigurationInput> = StytchB2BHeadlessClient<TProjectConfiguration> | StytchB2BUIClient<TProjectConfiguration>;
type SWRMemberUninitialized = {
    /**
     * Either the active {@link Member} object, or null if the member is not logged in.
     */
    member: null;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: false;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: false;
};
type SWRMemberInitialized = {
    /**
     * Either the active {@link Member} object, or null if the member is not logged in.
     */
    member: Member | null;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: boolean;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: true;
};
type SWRMember<TAlwaysInitialized extends boolean = boolean> = TAlwaysInitialized extends true ? SWRMemberInitialized : SWRMemberInitialized | SWRMemberUninitialized;
type SWRMemberSessionUninitialized = {
    /**
     * Either the active {@link MemberSession} object, or null if the member is not logged in.
     */
    session: null;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: false;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: false;
};
type SWRMemberSessionInitialized = {
    /**
     * Either the active {@link MemberSession} object, or null if the member is not logged in.
     */
    session: MemberSession | null;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: boolean;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: true;
};
type SWRMemberSession<TAlwaysInitialized extends boolean = boolean> = TAlwaysInitialized extends true ? SWRMemberSessionInitialized : SWRMemberSessionInitialized | SWRMemberSessionUninitialized;
type SWROrganizationUninitialized = {
    /**
     * Either the active {@link Organization} object, or null if the member is not logged in.
     */
    organization: null;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: false;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: false;
};
type SWROrganizationInitialized = {
    /**
     * Either the active {@link Organization} object, or null if the member is not logged in.
     */
    organization: Organization | null;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: boolean;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: true;
};
type SWROrganization<TAlwaysInitialized extends boolean = boolean> = TAlwaysInitialized extends true ? SWROrganizationInitialized : SWROrganizationInitialized | SWROrganizationUninitialized;
declare const useIsMounted__INTERNAL: () => boolean;
declare const isUIClient: <TProjectConfiguration extends Partial<import("@stytch/core/public").StytchProjectConfiguration>>(client: StytchB2BClient<TProjectConfiguration>) => client is StytchB2BUIClient<TProjectConfiguration>;
/**
 * Returns the active Member.
 * The Stytch SDKs are used for client-side authentication and session management.
 * Check the isInitialized property to determine if the SDK has completed initialization.
 * Check the fromCache property to determine if the member data is from persistent storage.
 * @example
 * const {member, isInitialized, fromCache} = useStytchMember();
 * if (!isInitialized) {
 *     return <p>Loading...</p>;
 * }
 * return (<h1>Welcome, {member.name}</h1>);
 */
declare const useStytchMember: <TAssumeHydrated extends boolean = false>() => SWRMember<TAssumeHydrated>;
/**
 * Returns the active member's Stytch member session.
 * The Stytch SDKs are used for client-side authentication and session management.
 * Check the isInitialized property to determine if the SDK has completed initialization.
 * Check the fromCache property to determine if the session data is from persistent storage.
 * @example
 * const {session, isInitialized, fromCache} = useStytchMemberSession();
 * useEffect(() => {
 *   if (!isInitialized) {
 *     return;
 *   }
 *   if (!session) {
 *     router.replace('/login')
 *   }
 * }, [session, isInitialized]);
 */
declare const useStytchMemberSession: <TAssumeHydrated extends boolean = false>() => SWRMemberSession<TAssumeHydrated>;
/**
 * Returns the active Stytch organization.
 * The Stytch SDKs are used for client-side authentication and session management.
 * Check the isInitialized property to determine if the SDK has completed initialization.
 * Check the fromCache property to determine if the organization data is from persistent storage.
 * @example
 * const {organization, isInitialized, fromCache} = useStytchOrganization();
 * if (!isInitialized) {
 *     return <p>Loading...</p>;
 * }
 * return (<p>Welcome to {organization.organization_name}</p>);
 */
declare const useStytchOrganization: <TAssumeHydrated extends boolean = false>() => SWROrganization<TAssumeHydrated>;
type SWRIsAuthorizedUninitialized = {
    /**
     * Whether the logged-in member is allowed to perform the specified action on the specified resource.
     */
    isAuthorized: false;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: false;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: false;
};
type SWRIsAuthorizedInitialized = {
    /**
     * Whether the logged-in member is allowed to perform the specified action on the specified resource.
     */
    isAuthorized: boolean;
    /**
     * If true, indicates that the value returned is from the application cache and a state refresh is in progress.
     */
    fromCache: boolean;
    /**
     * If true, indicates that the SDK has completed initialization.
     */
    isInitialized: boolean;
};
type SWRIsAuthorized<TAlwaysInitialized extends boolean> = TAlwaysInitialized extends true ? SWRIsAuthorizedInitialized : SWRIsAuthorizedInitialized | SWRIsAuthorizedUninitialized;
/**
 * Determines whether the logged-in member is allowed to perform the specified action on the specified resource.
 * Returns `true` if the member can perform the action, `false` otherwise.
 *
 * If the member is not logged in, this method will always return false.
 * If the resource or action provided are not valid for the configured RBAC policy, this method will return false.
 *
 * Remember - authorization checks for sensitive actions should always occur on the backend as well.
 * @example
 * const { isAuthorized } = useStytchIsAuthorized<Permissions>('documents', 'edit');
 * return <button disabled={!isAuthorized}>Edit</button>
 */
declare const useStytchIsAuthorized: <TAssumeHydrated extends boolean = false>(resourceId: string, action: string) => SWRIsAuthorized<TAssumeHydrated>;
/**
 * Returns the Stytch B2B client stored in the Stytch context.
 *
 * @example
 * const stytch = useStytchB2BClient();
 * useEffect(() => {
 *   stytch.magicLinks.authenticate('...')
 * }, [stytch]);
 */
declare const useStytchB2BClient: <TProjectConfiguration extends Partial<import("@stytch/core/public").StytchProjectConfiguration> = Stytch.DefaultProjectConfiguration>() => StytchB2BHeadlessClient<TProjectConfiguration>;
declare const withStytchB2BClient: <T extends object, TProjectConfiguration extends Partial<import("@stytch/core/public").StytchProjectConfiguration>>(Component: React.ComponentType<T & {
    stytch: StytchB2BHeadlessClient<TProjectConfiguration>;
}>) => React.ComponentType<T>;
declare const withStytchMember: <T extends object, TAssumeHydrated extends boolean = false>(Component: React.ComponentType<T & {
    stytchMember: Member | null;
    stytchMemberIsInitialized: boolean;
    stytchMemberIsFromCache: boolean;
}>) => React.ComponentType<T>;
declare const withStytchMemberSession: <T extends object, TAssumeHydrated extends boolean = false>(Component: React.ComponentType<T & {
    stytchMemberSession: MemberSession | null;
    stytchMemberSessionIsInitialized: boolean;
    stytchMemberSessionIsFromCache: boolean;
}>) => React.ComponentType<T>;
declare const withStytchOrganization: <T extends object, TAssumeHydrated extends boolean = false>(Component: React.ComponentType<T & {
    stytchOrganization: Organization | null;
    stytchOrganizationIsInitialized: boolean;
    stytchOrganizationIsFromCache: boolean;
}>) => React.ComponentType<T>;
/**
 * Wrap your component with this HOC in order to receive the permissions for the logged-in member.
 * Evaluates all permissions granted to the logged-in member.
 * Returns a Record<RoleId, Record<Action, boolean>> response indicating the member's permissions.
 * Each boolean will be `true` if the member can perform the action, `false` otherwise.
 *
 * If the member is not logged in, all values will be false.
 *
 * Remember - authorization checks for sensitive actions should always occur on the backend as well.
 * @example
 * type Permissions = {
 *   document: 'create' | 'read' | 'write
 *   image: 'create' | 'read'
 * }
 *
 * const MyComponent = (props) => {
 *   const canEditDocuments = props.stytchPermissions.document.edit;
 *   const canReadImages = props.stytchPermissions.image.read;
 * }
 * return withStytchPermissions<Permissions>(MyComponent)
 */
declare const withStytchPermissions: <Permissions_1 extends Record<string, string>, T extends object>(Component: React.ComponentType<T & {
    stytchPermissions: PermissionsMap<Permissions_1>;
}>) => React.ComponentType<T>;
interface StytchB2BProviderProps<TProjectConfiguration extends StytchProjectConfigurationInput = Stytch.DefaultProjectConfiguration> {
    /**
     * A Stytch client instance, created using either {@link createStytchHeadlessClient} or {@link createStytchUIClient}
     */
    stytch: StytchB2BClient<TProjectConfiguration>;
    /**
     * When true, the provider will assume that the component will only be
     * rendered in a browser environment, either in a single-page application or
     * after completing hydration of a server-rendered application. This allows
     * cached values to be retrieved from the browser on the first render, meaning
     * that the `isInitialized` value returned from Stytch hooks will be `true`
     * starting from the first render.
     *
     * When `false`, the provider will defer initialization until after the first
     * render, and `isInitialized` will initially be `false`.
     *
     * This value defaults to `false` in `@stytch/nextjs`.
     */
    assumeHydrated?: boolean;
    children?: ReactNode;
}
/**
 * The Stytch Context Provider.
 * Wrap your application with this component in order to use Stytch everywhere in your app.
 * @example
 * const stytch = createStytchB2BHeadlessClient('public-token-<find yours in the stytch dashboard>')
 *
 * return (
 *   <StytchB2BProvider stytch={stytch}>
 *     <App />
 *   </StytchB2BProvider>
 * )
 */
declare const StytchB2BProvider: <TProjectConfiguration extends Partial<import("@stytch/core/public").StytchProjectConfiguration> = Stytch.DefaultProjectConfiguration>({ stytch, children, assumeHydrated, }: StytchB2BProviderProps<TProjectConfiguration>) => JSX.Element;
export { useIsMounted__INTERNAL, isUIClient, useStytchMember, useStytchMemberSession, useStytchOrganization, useStytchIsAuthorized, useStytchB2BClient, withStytchB2BClient, withStytchMember, withStytchMemberSession, withStytchOrganization, withStytchPermissions, StytchB2BProviderProps, StytchB2BProvider };
